@@ -10,13 +10,13 @@ import warnings
 logging.getLogger("tensorflow").setLevel(logging.ERROR)
 logging.getLogger("matplotlib").setLevel(logging.ERROR)
 logging.getLogger("numba").setLevel(logging.WARNING)
+
 warnings.filterwarnings("ignore", message=".*binary incompatibility.*")
+warnings.filterwarnings("ignore", message=".*in favour of importlib.*")
 
 from contextlib import contextmanager
 
-with warnings.catch_warnings():
-    warnings.filterwarnings("ignore", message=".*binary incompatibility.*")
-    import numpy
+import numpy
 
 with warnings.catch_warnings():
     warnings.filterwarnings("ignore", message=".*as a synonym of type.*")
